@@ -26,13 +26,6 @@ def set(txt:str):
     subprocess.run(f'start /wait {dst.name}',shell=True)
     dst.unlink()
 
-def set2(txt:str):
-    qr = pyqrcode.create(txt)
-    print(qr.terminal())
-    # dst = Path('set.png')
-    # qr.png(dst,scale=10)
-    # subprocess.run(f'start /wait {dst.name}',shell=True)
-    # dst.unlink()
 
 def main():
     p = argparse.ArgumentParser()
@@ -45,7 +38,7 @@ def main():
     if args.cmd == 'get':
         get()
     elif args.cmd == 'set':
-        set2(args.text)
+        set(args.text)
     else:
         print(f'unhandled [{args.cmd}]')
 
